import time
import random
from flask import Blueprint, Response
from src.core.use_case import alerts_use_case

sse_routes = Blueprint("sse_routes", __name__, url_prefix="/sse")

@sse_routes.route("/alerts/", methods=["GET"])
def sse_alerts():
    """
    SSE endpoint to stream alerts
    """
    def generate():
        try:
            while True:
                new_data = alerts_use_case.get_next_alert(params={"type_alert": "test", "point": 1})['data']
                yield f"data: {new_data}\n\n"
                time.sleep(random.randint(1, 5))
        except GeneratorExit:
            print("SSE stream closed")
        except Exception as e:
            print(f"Error in SSE stream: {e}")

    return Response(generate(), content_type="text/event-stream", status=200)
